==> autopip-0.2.3.tar.gz: autopip-0.2.3/tests/test_crontab.py <==
from mock import Mock, call

from autopip import crontab


def test_add(mock_run, monkeypatch):
    monkeypatch.setattr('autopip.crontab.randint', Mock(return_value=10))
    crontab.add('echo hello')
    mock_run.assert_called_with('( crontab -l | grep -vF "echo hello"; '
                                'echo "10 * * * * PATH=/usr/local/bin:\$PATH echo hello" ) | crontab -',
                                shell=True, stderr=-2)

    crontab.add('echo hello', schedule='* * * * *')
    mock_run.assert_called_with('( crontab -l | grep -vF "echo hello"; '
                                'echo "* * * * * PATH=/usr/local/bin:\$PATH echo hello" ) | crontab -',
                                shell=True, stderr=-2)

    crontab.add('echo hello', schedule='* * * * *', cmd_id='hello')
    mock_run.assert_called_with('( crontab -l | grep -vF "hello"; '
                                'echo "* * * * * PATH=/usr/local/bin:\$PATH echo hello" ) | crontab -',
                                shell=True, stderr=-2)

    crontab.add('echo hello > /dev/null')
    mock_run.assert_called_with('( crontab -l | grep -vF "echo hello"; '
                                'echo "10 * * * * PATH=/usr/local/bin:\$PATH echo hello > /dev/null" ) | crontab -',
                                shell=True, stderr=-2)

    crontab.add('echo hello < /dev/null')
    mock_run.assert_called_with('( crontab -l | grep -vF "echo hello"; '
                                'echo "10 * * * * PATH=/usr/local/bin:\$PATH echo hello < /dev/null" ) | crontab -',
                                shell=True, stderr=-2)

    crontab.add('echo hello | tee /tmp/log')
    mock_run.assert_called_with('( crontab -l | grep -vF "echo hello"; '
                                'echo "10 * * * * PATH=/usr/local/bin:\$PATH echo hello | tee /tmp/log" ) | crontab -',
                                shell=True, stderr=-2)

    crontab.add('echo hello &> /dev/null')
    mock_run.assert_called_with('( crontab -l | grep -vF "echo hello"; '
                                'echo "10 * * * * PATH=/usr/local/bin:\$PATH echo hello &> /dev/null" ) | crontab -',
                                shell=True, stderr=-2)

    crontab.add('echo hello 2>&1 > /dev/null')
    mock_run.assert_called_with('( crontab -l | grep -vF "echo hello"; echo "10 * * * * '
                                'PATH=/usr/local/bin:\$PATH echo hello 2>&1 > /dev/null" ) | crontab -',
                                shell=True, stderr=-2)


def test_list(mock_run):
    crontab.list()
    mock_run.call_args_list == [
        call('which crontab'),
        call('pgrep cron'),
        call('crontab -l | grep autopip', shell=True, stderr=-2)]


def test_remove(mock_run):
    crontab.remove('hello')
    mock_run.assert_called_with('( crontab -l | grep -vF "hello" ) | crontab -',
                                shell=True, stderr=-2)

==> autopip-0.3.2.tar.gz: autopip-0.3.2/tests/test_crontab.py <==
from mock import Mock, call

from autopip import crontab


def test_add(mock_run, monkeypatch):
    monkeypatch.setattr('autopip.crontab.randint', Mock(return_value=10))
    crontab.add('echo hello')
    mock_run.assert_called_with('( crontab -l | grep -ivF "echo hello"; '
                                'echo "10 * * * * PATH=/usr/local/bin:\$PATH echo hello" ) | crontab -',
                                shell=True, stderr=-2)

    crontab.add('echo hello', schedule='* * * * *')
    mock_run.assert_called_with('( crontab -l | grep -ivF "echo hello"; '
                                'echo "* * * * * PATH=/usr/local/bin:\$PATH echo hello" ) | crontab -',
                                shell=True, stderr=-2)

    crontab.add('echo hello', schedule='* * * * *', cmd_id='hello')
    mock_run.assert_called_with('( crontab -l | grep -ivF "hello"; '
                                'echo "* * * * * PATH=/usr/local/bin:\$PATH echo hello" ) | crontab -',
                                shell=True, stderr=-2)

    crontab.add('echo hello > /dev/null')
    mock_run.assert_called_with('( crontab -l | grep -ivF "echo hello"; '
                                'echo "10 * * * * PATH=/usr/local/bin:\$PATH echo hello > /dev/null" ) | crontab -',
                                shell=True, stderr=-2)

    crontab.add('echo hello < /dev/null')
    mock_run.assert_called_with('( crontab -l | grep -ivF "echo hello"; '
                                'echo "10 * * * * PATH=/usr/local/bin:\$PATH echo hello < /dev/null" ) | crontab -',
                                shell=True, stderr=-2)

    crontab.add('echo hello | tee /tmp/log')
    mock_run.assert_called_with('( crontab -l | grep -ivF "echo hello"; '
                                'echo "10 * * * * PATH=/usr/local/bin:\$PATH echo hello | tee /tmp/log" ) | crontab -',
                                shell=True, stderr=-2)

    crontab.add('echo hello &> /dev/null')
    mock_run.assert_called_with('( crontab -l | grep -ivF "echo hello"; '
                                'echo "10 * * * * PATH=/usr/local/bin:\$PATH echo hello &> /dev/null" ) | crontab -',
                                shell=True, stderr=-2)

    crontab.add('echo hello 2>&1 > /dev/null')
    mock_run.assert_called_with('( crontab -l | grep -ivF "echo hello"; echo "10 * * * * '
                                'PATH=/usr/local/bin:\$PATH echo hello 2>&1 > /dev/null" ) | crontab -',
                                shell=True, stderr=-2)


def test_list(mock_run):
    crontab.list()
    mock_run.call_args_list == [
        call('which crontab'),
        call('pgrep cron'),
        call('crontab -l | grep autopip', shell=True, stderr=-2)]


def test_remove(mock_run):
    crontab.remove('hello')
    mock_run.assert_called_with('( crontab -l | grep -ivF "hello" ) | crontab -',
                                shell=True, stderr=-2)
